<template>
    <div class="playerContainer" ref="playerContainer">
        <div
            id="playWnd"
            class="playWnd"
            ref="playWnd"
            v-if="!showSetting"
            :style="`color:${theme === 'dark' ? '#fff' : '#000'}`"
        >
            {{ text }}
        </div>
        <div
            id="tipsWindow"
            v-else
            :style="`color:${theme === 'dark' ? '#fff' : '#000'}`"
        >
            <img
                v-if="theme !== 'dark'"
                :src="require('@/assets/img/empty.png')"
                alt="视频插件未安装"
                class="empty-img"
            />
            <h1>插件未安装或加载失败!</h1>
            <div>
                <h3>
                    若已安装视频插件，请尝试重启浏览器重试当前操作。<br />若问题任然存在，请检查网络或重新安装。
                </h3>
                <a
                    class="download-btn"
                    download="DSS_LightWeight_Client32.zip"
                    :href="downloadUrl32"
                >
                    <i class="el-icon-download"></i>
                    下载视频插件( 32 位)
                </a>
                <br />
                <a
                    class="download-btn"
                    download="DSS_LightWeight_Client.zip"
                    :href="downloadUrl64"
                >
                    <i class="el-icon-download"></i>
                    下载视频插件( 64 位)
                </a>
            </div>
        </div>
    </div>
</template>

<script>
import utils from '@/hotent-ui-util'
export default {
    components: {},
    props: {
        splitNum: {
            type: Number,
            default: 4,
        },
        autoPlay: {
            type: Boolean,
            default: false,
        },
        theme: {
            type: String,
            default: 'light',
        },
        ctrl: {
            type: String,
            default: 'ctrlsssb',
        },
    },
    data() {
        return {
            domId: 'playWnd',
            text: '视频插件加载中......',
            showSetting: false,
            isLogin: false,
            https: window.context.DHVideoHttps,
            loginIp: window.context.DHVideoIp,
            loginPort: window.context.DHVideoPort,
            userName: window.context.DHVideoAccount,
            userPwd: window.context.DHVideoPsd,
            downloadUrl32: '/fvue/static/plugin/DSS_LightWeight_Client32.zip',
            downloadUrl64: '/fvue/static/plugin/DSS_LightWeight_Client.zip',
            displayMode: 1, //1:实时视频; 2:视频回放
            // splitNum: 4,
            // ctrl: 'ctrlsssb', // 可生成多个控件
            ctrlType: 'playerWin', // 'playerWin': 播放控件';'realMonitorUI':'带设备树实时预览控件';'playbackUI':'带设备树视频回放控件';'TVWallUI':'视频上墙'
            crtPosX: 0,
            crtPosY: 0,
            crtWidth: 700,
            crtHeight: 400,
            channelId: '',
            // 插件对象实例，初始化为null，需要创建多个插件窗口时，需要定义多个插件对象实例变量，各个变量唯一标志对应的插件实例
            ws: null,
            bIE: !!window.ActiveXObject || 'ActiveXObject' in window, // 是否为IE浏览器
        }
    },
    methods: {
        createPlay(ctrlCode, channelId, size) {
            this.createVideoPlayer(ctrlCode, channelId, size)
        },
        realTimeVideo(channelId, ctrlCode) {
            console.log('realTimeVideo参数', ctrlCode, channelId)
            this.channelId = channelId
            if (this.ws.ctrls.length === 0) {
                this.$message.info('请先创建控件！')
            }
            const params = {
                ctrlCode: ctrlCode || this.ctrl,
                channelIds: [this.channelId],
            }
            this.ws.openCtrlPreview(params)
        },
        createVideoPlayer(ctrlCode, channelId, size) {
            let _this = this
            console.log('createVideoPlayer参数', ctrlCode, channelId, this.ctrl)
            const params = [
                {
                    ctrlType: this.ctrlType,
                    ctrlCode: ctrlCode || this.ctrl,
                    ctrlProperty: {
                        displayMode: this.displayMode,
                        splitNum: this.splitNum,
                    },
                    visible: true,
                    domId: this.domId,
                },
            ]

            _this.ws
                .createCtrl(params)
                .then((res) => {
                    console.log('控件创建成功', res)
                    this.setPos(ctrlCode, size)
                    if (ctrlCode) {
                        this.realTimeVideo(channelId, ctrlCode)
                    }
                })
                .catch((e) => {
                    console.log(e)
                })
            _this.ws.on('createCtrlResult', (res) => {
                console.log('createCtrlResult', res)
            })
        },

        // 设置窗口大小
        setPos(ctrlCode, size) {
            let path = this.$route.path
            let isIframe = path.indexOf('frontPlat') === -1
            this.$nextTick(() => {
                if (isIframe) {
                    this.getWindowSize()
                    this.setCtrlPos(isIframe, ctrlCode, size)
                } else {
                    setTimeout(() => {
                        this.getWindowSize()
                        this.setCtrlPos(isIframe, ctrlCode, size)
                    }, 500)
                }
            })
        },
        setCtrlPos(isIframe, ctrlCode, size) {
            let height = this.crtHeight
            let crtPosY = this.crtPosY
            let crtPosX = this.crtPosX
            let crtWidth = this.crtWidth
            if (size === 'top') {
                height = parseInt((this.crtWidth / 16) * 9)
            } else if (size === 'bottom') {
                height = parseInt((this.crtWidth / 16) * 9)
                crtPosY = this.crtPosY + this.crtHeight - height
            }

            let iframeHeight = 0
            let iframeLeft = 0
            let iframewidth = 0
            if (isIframe) {
                iframeHeight = 94
                let path = this.$route.path
                if (path.indexOf('VideoMonitor') !== -1) {
                    // 视频监控页面的宽度加100
                    iframewidth = 100
                    iframeLeft = 20
                } else {
                    // 其他的左侧位移100
                    iframeLeft = 100
                }
            }

            this.ws.setCtrlPos([
                {
                    ctrlCode: ctrlCode || this.ctrl,
                    posX: crtPosX + iframeLeft,
                    posY: crtPosY + iframeHeight,
                    width: crtWidth + iframewidth,
                    height: height,
                },
            ])
        },
        // 登录视频插件
        login() {
            this.ws.login({
                loginIp: this.loginIp,
                loginPort: this.loginPort,
                userName: this.userName,
                userPwd: this.userPwd,
                https: this.https,
            })
            this.ws.on('loginState', (res) => {
                this.isLogin = res
                if (res) {
                    console.log('登录成功')
                    this.text = ''
                    if (this.autoPlay) {
                        console.log('已准备好播放，自动')
                        this.$emit('ready')
                    } else {
                        console.log('已准备好播放，手动')
                        this.createVideoPlayer() // 创建视频插件
                    }
                } else {
                    this.text = '视频插件登录失败，请联系管理员！'
                }
            })
        },
        // 获取窗口宽高
        getWindowSize() {
            const playerDomSize =
                this.$refs.playerContainer.getBoundingClientRect()
            this.crtPosX = playerDomSize.x
            this.crtPosY = playerDomSize.y
            this.crtWidth = playerDomSize.width
            this.crtHeight = playerDomSize.height
            console.log(
                '视窗参数位置参数',
                this.crtPosX,
                this.crtPosY,
                this.crtWidth,
                this.crtHeight,
                this.$refs.playerContainer.getBoundingClientRect()
            )
        },
        closeVideo(ctrlCode) {
            if (this.ws) {
                this.ws.closeCtrlVideo([ctrlCode || this.ctrl])
            }
        },
        closePlugin() {
            if (this.ws) {
                this.ws.logout()
                const ctrls = this.ws.ctrls.map((i) => {
                    if (i.ctrlCode === this.ctrl) {
                        return i.ctrlCode
                    }
                })
                this.ws.destroyCtrl(ctrls)
            }
        },
    },
    mounted() {
        const DHWsInstance = DHWs.getInstance()
        this.ws = DHWsInstance
        console.log(this.ctrl, 'this.ctrl')
        this.ws
            .detectConnectQt()
            .then((res) => {
                if (res) {
                    console.log('连接成功')
                    this.login()
                } else {
                    this.$message.info('连接失败，请下载客户端')
                    this.showSetting = true
                    this.text = ''
                }
            })
            .catch((err) => {
                console.log(err, 'detectConnectQt')
            })
        window.addEventListener('onunload', () => {
            this.closePlugin()
        })
    },
    beforeDestroy() {
        this.closePlugin()
    },
}
</script>

<style lang="scss" scoped>
$border-color: #566a7e;
$active-color: #409eff;
$high-light-color: #ff7c40;
$text-color:#b7c6d8;
$text-color-dark:#8993a0;
$dark-bg:#0b1926;
$dark-bg-lighter: #1d3b57;
.playerContainer {
    width: 100%;
    height: 100%;
    box-sizing: border-box;
    position: relative;
}
#playWnd{
    width: 100%;
    height: 100%;
    background-color:transparent;
    display: flex;
    justify-content: center;
    align-items: center;
    font-size: 16px;
}
#tipsWindow{
    width: 100%;
    height: 100%;
    background-color: rgba($dark-bg, 0.2);
    text-align: center;
    .empty-img{
        display: inline-block;
        width: 26%;
        margin:0 auto;
    }
    h1{
        font-size: 24px;
    }
    h3{
        font-size: 14px;
    }
}

.download-btn{
    color: $active-color;
    text-decoration: none;
    cursor: pointer;
    font-size: 18px;
    font-weight: 700;
    i{
        font-size: 18px;
    }
}
</style>